==> igniteui-react-core-18.2.0-beta.2.tgz: package/esm2015/lib/StackedSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSeriesCreatedEventArgsDescriptionMetadata } from "./StackedSeriesCreatedEventArgsDescriptionMetadata";
import { CategorySeriesDescriptionMetadata } from "./CategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let StackedSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (StackedSeriesBaseDescriptionMetadata.a == null) {
                StackedSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedSeriesBaseDescriptionMetadata.c(StackedSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(StackedSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ab(StackedSeriesBaseDescriptionMetadata.a);
            StackedSeriesCreatedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            CategorySeriesDescriptionMetadata.c(a);
            a.item("Series", "Collection:StackedFragmentSeries:StackedSeriesCollection:StackedFragmentSeries");
            a.item("AutoGenerateSeries", "Boolean");
            a.item("ReverseLegendOrder", "Boolean");
            a.item("SeriesCreatedRef", "EventRef::seriesCreated");
            StackedSeriesBaseDescriptionMetadata.e(a);
        }
        static d(a) {
            StackedSeriesBaseDescriptionMetadata.b(a);
            a.ac("StackedSeriesBase", StackedSeriesBaseDescriptionMetadata.a);
        }
        static e(a) {
        }
    }
    StackedSeriesBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedSeriesBaseDescriptionMetadata, 'StackedSeriesBaseDescriptionMetadata');
    StackedSeriesBaseDescriptionMetadata.a = null;
    return StackedSeriesBaseDescriptionMetadata;
})();

==> igniteui-react-core-18.7.0-beta.2.tgz: package/esm2015/lib/StackedSeriesBaseDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedSeriesCreatedEventArgsDescriptionMetadata } from "./StackedSeriesCreatedEventArgsDescriptionMetadata";
import { CategorySeriesDescriptionMetadata } from "./CategorySeriesDescriptionMetadata";
/**
 * @hidden
 */
export let StackedSeriesBaseDescriptionMetadata = /*@__PURE__*/ (() => {
    class StackedSeriesBaseDescriptionMetadata extends Base {
        static b(a) {
            if (StackedSeriesBaseDescriptionMetadata.a == null) {
                StackedSeriesBaseDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                StackedSeriesBaseDescriptionMetadata.c(StackedSeriesBaseDescriptionMetadata.a);
            }
            if (a.k(StackedSeriesBaseDescriptionMetadata.a)) {
                return;
            }
            a.ac(StackedSeriesBaseDescriptionMetadata.a);
            StackedSeriesCreatedEventArgsDescriptionMetadata.d(a);
        }
        static c(a) {
            CategorySeriesDescriptionMetadata.c(a);
            a.item("Series", "Collection:StackedFragmentSeries:StackedSeriesCollection:StackedFragmentSeries");
            a.item("AutoGenerateSeries", "Boolean");
            a.item("ReverseLegendOrder", "Boolean");
            a.item("SeriesCreatedRef", "EventRef::seriesCreated");
            StackedSeriesBaseDescriptionMetadata.e(a);
        }
        static d(a) {
            StackedSeriesBaseDescriptionMetadata.b(a);
            a.ad("StackedSeriesBase", StackedSeriesBaseDescriptionMetadata.a);
        }
        static e(a) {
        }
    }
    StackedSeriesBaseDescriptionMetadata.$t = /*@__PURE__*/ markType(StackedSeriesBaseDescriptionMetadata, 'StackedSeriesBaseDescriptionMetadata');
    StackedSeriesBaseDescriptionMetadata.a = null;
    return StackedSeriesBaseDescriptionMetadata;
})();
